
# Slot: description


A human-readable description for a thing

URI: [nwb_schema_language:description](https://w3id.org/p2p_ld/nwb-schema-language/description)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [NamedThing](NamedThing.md)
 * [Namespaces](Namespaces.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | schema:description |

